Documentation
¶
Index ¶
Constants ¶
const (
ScrollAmount = 10 // Number of lines to scroll in diff view
)
Constants for UI behavior
Variables ¶
This section is empty.
Functions ¶
Types ¶
type ConfirmDialog ¶
ConfirmDialog represents a yes/no confirmation dialog
type DiffLine ¶
type DiffLine struct {
Type DiffLineType
Content string
OldLine int
NewLine int
HunkID int
FileName string
}
DiffLine represents a single line in the diff view
type DiffLineType ¶
type DiffLineType int
DiffLineType represents the type of diff line
const ( DiffLineContext DiffLineType = iota DiffLineAdded DiffLineRemoved DiffLineHeader DiffLineFileHeader DiffLineHunkHeader DiffLineNoNewline )
type DiffMode ¶
type DiffMode struct {
// contains filtered or unexported fields
}
DiffMode represents the diff viewer state
type Model ¶
type Model struct {
// contains filtered or unexported fields
}
Model represents the main TUI state
func (Model) GetAttachOnExit ¶
GetAttachOnExit returns the session to attach to when exiting TUI
type NewSessionDialog ¶
NewSessionDialog represents a new session creation dialog
Click to show internal directories.
Click to hide internal directories.